/*
This file is part of the Juju GUI, which lets users view and manage Juju
environments within a graphical interface (https://launchpad.net/juju-gui).
Copyright (C) 2015 Canonical Ltd.

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License version 3, as published by
the Free Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero
General Public License for more details.

You should have received a copy of the GNU Affero General Public License along
with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

'use strict';

YUI.add('deployment-choose-cloud', function () {

  juju.components.DeploymentChooseCloud = React.createClass({

    propTypes: {
      changeState: React.PropTypes.func.isRequired,
      cloudData: React.PropTypes.object.isRequired,
      jem: React.PropTypes.object.isRequired,
      setDeploymentInfo: React.PropTypes.func.isRequired
    },

    getInitialState: function getInitialState() {
      return {
        credentials: [],
        clouds: []
      };
    },

    componentWillMount: function componentWillMount() {
      var _this = this;

      this.props.jem.listTemplates(function (error, credentials) {
        // XXX kadams54: This is basic error handling for the initial
        // implementation. It should be replaced with an error message for the
        // user in subsequent UI polish work.
        if (error) {
          console.error('Unable to list templates', error);
          return;
        }
        _this.setState({ credentials: credentials });
      });
      this.props.jem.listClouds(function (error, clouds) {
        if (error) {
          console.error('Unable to list clouds', error);
          return;
        }
        _this.setState({ clouds: clouds });
      });
    },

    /**
      Generate the list of credentials.
       @method _generateCredentials
    */
    _generateCredentials: function _generateCredentials() {
      var _this2 = this;

      var credentials = this.state.credentials;
      var components = [];
      credentials.forEach(function (credential, i) {
        var path = credential.path;
        var parts = path.split('/');
        var owner = parts[0];
        var name = parts[1];
        var className = classNames('deployment-choose-cloud__cloud-option', 'deployment-choose-cloud__cloud-option--credential', 'six-col', { 'last-col': i % 2 === 1 });
        components.push(React.createElement(
          'li',
          { className: className,
            key: credential.path,
            onClick: _this2._handleCredentialClick.bind(_this2, credential.path) },
          React.createElement(
            'span',
            { className: 'deployment-choose-cloud__cloud-option-title' },
            React.createElement(
              'span',
              { className: 'deployment-choose-cloud__cloud-option-name' },
              name
            ),
            React.createElement(
              'span',
              { className: 'deployment-choose-cloud__cloud-option-owner' },
              owner
            )
          )
        ));
      });
      return React.createElement(
        'div',
        null,
        React.createElement(
          'h3',
          { className: 'deployment-panel__section-title twelve-col' },
          'Saved cloud credentials'
        ),
        React.createElement(
          'ul',
          { className: 'deployment-choose-cloud__list twelve-col' },
          components
        ),
        React.createElement(
          'h3',
          { className: 'deployment-panel__section-title twelve-col' },
          'Public clouds'
        )
      );
    },

    /**
      Generate a list of cloud options.
       @method _generateCloudOptions
      @returns {Array} The collection of changes.
    */
    _generateCloudOptions: function _generateCloudOptions() {
      var _this3 = this;

      var components = [];
      // XXX This is commented out here only for the DEMO and should be
      // removedshortly thereafter so we only display the clouds which we
      // have controllers for.
      //this.state.clouds.forEach((cloud, i) => {
      ['aws', 'azure', 'google'].forEach(function (cloud, i) {
        var option = _this3.props.cloudData[cloud];
        var lastCol = i % 3 === 2 ? 'last-col' : '';
        var className = 'deployment-choose-cloud__cloud-option four-col ' + lastCol;
        components.push(React.createElement(
          'li',
          { className: className,
            key: option.id,
            onClick: _this3._handleCloudClick.bind(_this3, option.id) },
          React.createElement(
            'span',
            { className: 'deployment-choose-cloud__cloud-option-image' },
            React.createElement(juju.components.SvgIcon, {
              height: option.svgHeight,
              name: option.id,
              width: option.svgWidth })
          )
        ));
      });
      return React.createElement(
        'ul',
        { className: 'deployment-choose-cloud__list twelve-col' },
        components
      );
    },

    /**
      Generate the onboarding message for loading the available clouds.
       @method _generateCloudOnboarding
      @returns {Object} The onboarding message.
    */
    _generateCloudOnboarding: function _generateCloudOnboarding() {
      return React.createElement(
        'div',
        { className: 'deployment-panel__notice twelve-col' },
        React.createElement(
          'p',
          { className: 'deployment-panel__notice-content' },
          React.createElement(juju.components.SvgIcon, {
            name: 'general-action-blue',
            size: '16' }),
          'Fetching available clouds...'
        )
      );
    },

    /**
      Handling clicking on a cloud option.
       @method _handleCloudClick
    */
    _handleCloudClick: function _handleCloudClick(id) {
      this.props.setDeploymentInfo('cloud', id);
      this.props.changeState({
        sectionC: {
          component: 'deploy',
          metadata: {
            activeComponent: 'add-credentials-' + id
          }
        }
      });
    },

    /**
      Handling clicking on an existing credential option.
       @method _handleCredentialClick
    */
    _handleCredentialClick: function _handleCredentialClick(id) {
      this.props.setDeploymentInfo('templateName', id);
      this.props.changeState({
        sectionC: {
          component: 'deploy',
          metadata: {
            activeComponent: 'summary'
          }
        }
      });
    },

    /**
      Generate the onboarding if there are no credentials.
       @method _generateCredentialsOnboarding
    */
    _generateCredentialsOnboarding: function _generateCredentialsOnboarding() {
      return React.createElement(
        'div',
        { className: 'deployment-panel__notice twelve-col' },
        React.createElement(
          'p',
          { className: 'deployment-panel__notice-content' },
          React.createElement(juju.components.SvgIcon, {
            name: 'general-action-blue',
            size: '16' }),
          'Add a public cloud credential, and we can save it as an option for later use'
        )
      );
    },

    render: function render() {
      var credentialsLength = this.state.credentials.length;
      var cloudsLength = this.state.clouds.length;
      var title = credentialsLength === 0 ? 'Choose cloud' : 'Choose cloud or saved credential';
      return React.createElement(
        'div',
        { className: 'deployment-panel__child' },
        React.createElement(
          juju.components.DeploymentPanelContent,
          {
            title: title },
          credentialsLength ? this._generateCredentials() : this._generateCredentialsOnboarding(),
          cloudsLength ? this._generateCloudOptions() : this._generateCloudOnboarding(),
          React.createElement(
            'div',
            { className: 'deployment-choose-cloud__download twelve-col' },
            React.createElement(juju.components.SvgIcon, {
              height: '30',
              name: 'juju-logo',
              width: '75' }),
            'Deploy manually using Juju to OpenStack, Vmware, MAAS, Joyent or locally to your computer',
            React.createElement(
              'a',
              { className: 'deployment-choose-cloud__download-button ' + 'button--inline-neutral',
                href: 'https://jujucharms.com/docs/stable/reference-releases',
                target: '_blank' },
              'Download Juju'
            )
          )
        )
      );
    }
  });
}, '0.1.0', { requires: ['deployment-panel-content', 'svg-icon'] });